.. _examples:

#################
Evolving binaries
#################

COSMIC can evolve binaries for several different use cases. Go through the examples below to learn more about these capabilities.

.. toctree::
    :maxdepth: 1

    evolve/single
    evolve/multiple
    evolve/grid
    evolve/evolve_sample
    evolve/resolution
    evolve/restart

